@@ -26,10 +26,12 @@
 
 #include "eel-caption.h"
 
+#include "eel-accessibility.h"
 #include "eel-gtk-macros.h"
 #include "eel-glib-extensions.h"
 #include "eel-art-gtk-extensions.h"
 
+#include <atk/atkrelationset.h>
 #include <gtk/gtklabel.h>
 #include <gtk/gtkentry.h>
 
@@ -232,6 +234,7 @@ eel_caption_set_child (EelCaption *caption,
 
 	caption->detail->child = child;
 	gtk_label_set_mnemonic_widget (GTK_LABEL (caption->detail->title_label), child);
+	eel_accessibility_set_up_label_widget_relation (caption->detail->title_label, child);
 	
 	gtk_box_pack_start (GTK_BOX (caption),
 			    caption->detail->child,
